.. _product:

Products
********

.. automodule:: networkx.algorithms.product
.. autosummary::
   :toctree: generated/

   cartesian_product
   lexicographic_product
   strong_product
   tensor_product



